"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * class for express request handling
 */
class Handlers {
    /**
     *
     * @param options HandlersOptions
     */
    constructor(options) {
        this.tokenGenerator = options.tokenGenerator;
    }
    /**
     *
     * @param req Request
     * @param res Response
     */
    async generateComponentToken(req, res) {
        /** expected inputs
         * {
         *   "domain": "string",
         *   "room": "string",
         *   "tenant": "string",
         *   "tokenType": "JIGASI"
         * }
         **/
        const inputs = {
            ...req.params,
            ...req.body
        };
        req.context.logger.debug('inputs', { inputs,
            body: req.body,
            params: req.params });
        const payload = {
            room: inputs.room ? inputs.room : '*'
        };
        const signOptions = {
            issuer: 'jaas-components',
            expiresIn: '1 day'
        };
        if (inputs.tenant) {
            signOptions.subject = inputs.tenant;
        }
        else if (inputs.domain) {
            signOptions.subject = inputs.domain;
        }
        else {
            signOptions.subject = '*';
        }
        switch (inputs.tokenType) {
            case 'JIGASI':
                // inject any jigasi specifics here
                signOptions.audience = `jigasi.${inputs.domain}`;
                break;
        }
        const token = this.tokenGenerator.clientToken(req.context, payload, signOptions);
        res.status(200).json({ token });
    }
    /**
     *
     * @param req Request
     * @param res Response
     */
    async generateServerToken(req, res) {
        let signOptions = {
            audience: 'jitsi-token-generator',
            expiresIn: '1 hour'
        };
        if (req.params) {
            signOptions = {
                ...signOptions,
                ...req.params
            };
        }
        if (req.body) {
            signOptions = {
                ...signOptions,
                ...req.body
            };
        }
        const token = this.tokenGenerator.serverToken(req.context, signOptions);
        res.status(200).json({ token });
    }
}
exports.default = Handlers;
